@@ -1,8 +1,12 @@
+import uuid
 from dataclasses import dataclass, field
-from typing import Optional
-
+@dataclass
 class Contact:
+  id: uuid.UUID
+  carrier_id: uuid.UUID
   first_name: str = field(default=None)
   last_name: str = field(default=None)
   phone: str = field(default=None)
-  email_address: str = field(default=None)
\ No newline at end of file
+  mobile: str = field(default=None)
+  email_address: str = field(default=None)
+  primary_contact: bool = field(default=False)
