@@ -23,6 +23,9 @@ class Config(object):
   PARSED_CARRIER_SNS_TOPIC_ARN = 'arn:aws:sns:us-west-1:791608169866:mcleod-parsed-carrier-test'
   PARSED_CARRIER_SNS_SUBJECT = 'parsed-carrier'
   PARSED_CARRIER_SNS_CLASS_NAME = 'com.cargochief.sdk.carrierhub.notifications.ParsedCarrierNotification'
+  BOOK_LOAD_SNS_TOPIC_ARN = 'arn:aws:sns:us-west-1:791608169866:booking-agent-book-load-test'
+  BOOK_LOAD_SNS_SUBJECT = 'book-load'
+  BOOK_LOAD_SNS_CLASS_NAME = 'com.cargochief.sdk.bookingagent.sns.BookLoadNotification'
 
 class LocalConfig(Config):
   """Configurations for running and debugging locally, with a separate local database."""
@@ -40,6 +43,7 @@ class DevelopmentConfig(Config):
 class ProductionConfig(Config):
   """Configurations for running in dev mode, with a remote database."""
   PARSED_CARRIER_SNS_TOPIC_ARN = 'arn:aws:sns:us-west-1:791608169866:mcleod-parsed-carrier-prod'  
+  BOOK_LOAD_SNS_TOPIC_ARN = 'arn:aws:sns:us-west-1:791608169866:booking-agent-book-load-prod'
 
 config_options = {
     'local': LocalConfig,
